@@ -4,7 +4,7 @@ import gtk
 import gobject
 import random
 
-VERSION = "0.3.5.2"
+VERSION = "0.3.7"
 IS_MAEMO = commands.getoutput("uname -m")[0:3] == "arm" # if cpu type is ARM, we are on maemo
 
 # general settings
@@ -13,10 +13,6 @@ music_dirs = ("~/music/", "/media/mmc2", "/media/mmc1")
 blacklist_dirs = ("/media/mmc2/map",)
 known_exts = ("mp3", "ogg")
 
-if IS_MAEMO:
-    import osso
-    context = osso.Context("youamp", VERSION, False)
-
 # device specific settings
 if IS_MAEMO:
     MAX_VOL = 10.0
