@@ -31,12 +31,18 @@ class Controller:
         program.add_window(self._window)
         program.set_property("can-hibernate", True)
         
+        # RPC
+        if IS_MAEMO:
+            osso_rpc = osso.Rpc(osso_c)
+            osso_rpc.set_rpc_callback("net.rojtberg.youamp", \
+                                      "/net/rojtberg/youamp", \
+                                      "net.rojtberg.youamp", self._handle_rpc)
+        
         # dialogs
         self._about_dialog = None
         self._preferences = None
         
-        if IS_MAEMO:
-            gtk.set_application_name("YouAmp")
+        gobject.set_application_name("YouAmp")
             
         # menu
         menu = gtk.Menu()
@@ -66,15 +72,12 @@ class Controller:
         
         self._order_menu = dict()
         self._order_menu["artist"] = gtk.RadioMenuItem(None, _("Artist"))
-        self._order_menu["artist"].connect("activate", lambda caller: self._set_list_order("artist"))
         self._order_menu["date"] = gtk.RadioMenuItem(self._order_menu["artist"], _("Date added"))
-        self._order_menu["date"].connect("activate", lambda caller: self._set_list_order("date"))
         self._order_menu["playcount"] = gtk.RadioMenuItem(self._order_menu["artist"], _("Playcount"))
-        self._order_menu["playcount"].connect("activate", lambda caller: self._set_list_order("playcount"))
 
         for k in ("artist", "date", "playcount"):
             order_sub.append(self._order_menu[k])
-
+     
         prefs = gtk.ImageMenuItem(gtk.STOCK_PREFERENCES)
         prefs.connect("activate", self._show_preferences)
         menu.append(prefs)
@@ -96,18 +99,31 @@ class Controller:
         if not self._config["shuffle"]:
             self._order_menu[self._config["order-by"]].set_active(True)
 
-        # signals
+        # window signals
         self._window.connect("destroy", self.quit)
         self._window.connect("key-press-event", self._on_key_press)
         self._player.connect("song-played", self._on_song_played)
-      
+
+        # order signals
+        self._order_menu["artist"].connect("activate", lambda caller: self._set_list_order("artist"))
+        self._order_menu["date"].connect("activate", lambda caller: self._set_list_order("date"))
+        self._order_menu["playcount"].connect("activate", lambda caller: self._set_list_order("playcount"))
+
         # banner
         self._banner = hildon.hildon_banner_show_animation(self._window, "qgn_indi_pball_a", _("Updating database"))
         self._library.connect("update-complete", self._destroy_banner)
 
         # start updating thread
         self._library.update()
-
+    
+    def _handle_rpc(self, interface, method, arguments, user_data):
+        action = dict();
+        action["toggle"] = self._window._controls.on_toggle
+        action["prev"] = self._window._controls.on_prev
+        action["next"] = self._window._controls.on_next
+        
+        action[method]()
+    
     def _check_config(self):
         if not self._config.has_key("volume"):
             # write default config
@@ -157,7 +173,7 @@ class Controller:
         key = gtk.gdk.keyval_name(event.keyval)
         
         if key == "Right":
-            self._window._controls.on_next()
+            self._player.next()
             return True # event handled
         elif key == "Left":
             self._window._controls.on_prev()
