@@ -148,13 +148,13 @@ class Library(GObject, Thread):
                 try:
                     f = mutagen.easyid3.EasyID3(path)
                 except ID3NoHeaderError:
-                    print "Bad ID3 Header, skipping: %s" % path
+                    sys.stderr.write("Bad ID3 Header, skipping: %s" % path)
                     continue
             else:
                 f = mutagen.File(path)
                 
             if f is None:
-                print "Not a media file, skipping: %s" % path
+                sys.stderr.write("Not a media file, skipping: %s" % path)
                 continue
             
             for k, v in f.items():
@@ -162,7 +162,7 @@ class Library(GObject, Thread):
                 try:
                     v = str(", ".join(v))   # flatten value
                 except TypeError:
-                    print "wrong type for %s in %s" % (k, path)
+                    sys.stderr.write("wrong type for %s in %s" % (k, path))
                     continue
                 
                 if k == "tracknumber":                        
